@@ -111,6 +111,9 @@ class DALService:
         return q
 
     def describe(self):
+        """
+        describe the general information about the DAL service
+        """
         print('DAL Service at {}'.format(self.baseurl))
 
 
@@ -132,7 +135,7 @@ class DALQuery(dict):
         """
         initialize the query object with a baseurl
         """
-        if type(baseurl) == bytes:
+        if isinstance(baseurl, bytes):
             baseurl = baseurl.decode("utf-8")
 
         self._baseurl = baseurl.rstrip("?")
