@@ -503,7 +503,7 @@ class SIAQuery(DALQuery):
     def format(self, format_):
         setattr(self, "_format", format_)
 
-        if type(format_) in (str, bytes):
+        if isinstance(format_, (str, bytes)):
             format_ = [format_]
 
         self["FORMAT"] = ",".join(_.upper() for _ in format_)
@@ -878,11 +878,10 @@ class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         to retrieve the dataset described by this record.  None is returned
         if no such column exists.
         """
-        dataurl = super().getdataurl()
-        if dataurl is None:
+        if self.acref is not None:
             return self.acref
         else:
-            return dataurl
+            return super().getdataurl()
 
     def suggest_dataset_basename(self):
         """
@@ -893,7 +892,7 @@ class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         ``make_dataset_filename()``.
         """
         out = self.title
-        if type(out) == bytes:
+        if isinstance(out, bytes):
             out = out.decode('utf-8')
 
         if not out:
