@@ -3,14 +3,11 @@
 """
 Tests for pyvo.dal.datalink
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 from astropy.table import Table
 from astropy.utils.data import get_pkg_data_filename
 
 
 def test_monkeypatch():
     Table.read(get_pkg_data_filename("data/monkeypatch.xml"))
-    import pyvo
+    import pyvo  # noqa: F401
     Table.read(get_pkg_data_filename("data/monkeypatch.xml"))
