@@ -5,10 +5,7 @@ Tests for pyvo.dal.query
 """
 from functools import partial
 
-try:
-    from contextlib import ExitStack
-except ImportError:
-    from contextlib2 import ExitStack
+from contextlib import ExitStack
 
 from os import listdir
 
@@ -19,8 +16,7 @@ import numpy as np
 import platform
 
 from pyvo.dal.query import DALService, DALQuery, DALResults, Record
-from pyvo.dal.exceptions import DALServiceError, DALQueryError,\
-    DALFormatError, DALOverflowWarning
+from pyvo.dal.exceptions import DALServiceError, DALQueryError, DALFormatError, DALOverflowWarning
 from pyvo.version import version
 
 from astropy.table import Table
